@@ -14,6 +14,11 @@ import aws_cdk.aws_ecs
 import aws_cdk.aws_iam
 import aws_cdk.core
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-batch", "1.33.0", __name__[0:-6], "aws-batch@1.33.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
